@@ -2,14 +2,12 @@
 
 from __future__ import unicode_literals
 from .. import Provider as SsnProvider
-from faker.generator import random
 
 
 class Provider(SsnProvider):
     ssn_formats = ("###.####.####.##",)
 
-    @classmethod
-    def ssn(cls):
+    def ssn(self):
         """
         Returns a 13 digits Swiss SSN named AHV (German) or
                                             AVS (French and Italian)
@@ -22,7 +20,7 @@ class Provider(SsnProvider):
 
         digits = [7, 5, 6]
         # create an array of first 9 elements initialized randomly
-        digits += random.sample(range(10), 9)
+        digits += self.generator.random.sample(range(10), 9)
         # determine the last digit to make it qualify the test
         digits.append(_checksum(digits))
         # repeat steps until it does qualify the test
